# -*- encoding: utf-8 -*-
from openerp import models, fields, api, tools
from openerp.exceptions import ValidationError

class CarService(models.Model):
    _name = 'car.service'

    name=fields.Char('Modelo y Número de chapa', required=True)

    logo = fields.Binary('Logo File')
    partner_id = fields.Many2one(
        'res.partner',
        string='Cliente',
        ondelete='restrict'
    )
    description = fields.Text('Description', translate=True)
    policy = fields.Boolean()
    agent_id = fields.Many2one(
        'res.partner',
        string='Agente',
        ondelete='restrict'
    )
    secure_id = fields.Many2one(
        'res.partner',
        string='Aseguradora',
        ondelete='restrict'
    )
    odometer = fields.Float('Odometro')
    car_value = fields.Float('Valor del vehiculo')
    transmission = fields.Selection([('manual','Manual'), ('automatic','Automatico')], string="Tipo de transmision")
    fuel_type = fields.Selection([('gasoline','Gasolina'), ('diesel','Diesel'), ('electric','Electrico'), ('hybrid','Hibrido')], string="Tipo de combustible")
    seats = fields.Integer('Nro. de asientos')
    doors = fields.Integer('Nro. de puertas')
    car_brand_id = fields.Many2one(
        'car.brand',
        string='Marca'
    )
    @api.one
    @api.constrains('name')
    def _controla_ruc(self):
        part_obj = self.env['car.service'].search([('name','=',self.name)])
        if len(part_obj) > 1:
            raise ValidationError('La chapa del vehículo debe ser único')


class CarBrand(models.Model):
    _name = 'car.brand'

    name = fields.Char('Brand Name', required=True)
    description = fields.Text('Description', translate=True)
    logo = fields.Binary('Logo File')
    car_ids = fields.One2many(
        'car.service',
        'car_brand_id',
    )
    car_count = fields.Integer(
        string='Numero de autos',
        compute='_get_car_count',
    )

    @api.one
    @api.depends('car_ids')
    def _get_car_count(self):
        self.car_count = len(self.car_ids)
